==> abiword-2.5.1.tar.gz: abiword-2.5.1/src/wp/ap/xp/ap_TB_Layouts_FileEditOps.h <==
/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */

/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */


/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

BeginLayout(FileEditOps, AP_STRING_ID_TB_Standard, AP_PREF_KEY_StandardBarVisible)

	ToolbarItem(AP_TOOLBAR_ID_FILE_NEW)
	ToolbarItem(AP_TOOLBAR_ID_FILE_OPEN)
	ToolbarItem(AP_TOOLBAR_ID_FILE_SAVE)
	Spacer()
#ifdef XP_UNIX_TARGET_GTK
	ToolbarItem(AP_TOOLBAR_ID_FILE_PRINT_PREVIEW)
#endif
	ToolbarItem(AP_TOOLBAR_ID_FILE_PRINT)

	Spacer()
	ToolbarItem(AP_TOOLBAR_ID_EDIT_UNDO)
	ToolbarItem(AP_TOOLBAR_ID_EDIT_REDO)

	Spacer()
	ToolbarItem(AP_TOOLBAR_ID_EDIT_CUT)
	ToolbarItem(AP_TOOLBAR_ID_EDIT_COPY)
	ToolbarItem(AP_TOOLBAR_ID_EDIT_PASTE)

	Spacer()
#ifndef WITHOUT_SPELL
	ToolbarItem(AP_TOOLBAR_ID_SPELLCHECK)
#endif
	ToolbarItem(AP_TOOLBAR_ID_ZOOM)
EndLayout()

==> abiword_2.8.2.orig.tar.gz: abiword-2.8.2/src/wp/ap/xp/ap_TB_Layouts_FileEditOps.h <==
/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */

/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

BeginLayout(FileEditOps, AP_STRING_ID_TB_Standard, AP_PREF_KEY_StandardBarVisible)

	ToolbarItem(AP_TOOLBAR_ID_FILE_NEW)
	ToolbarItem(AP_TOOLBAR_ID_FILE_OPEN)
	ToolbarItem(AP_TOOLBAR_ID_FILE_SAVE)
	Spacer()
#if defined(TOOLKIT_GTK) || defined (TOOLKIT_WIN)
	ToolbarItem(AP_TOOLBAR_ID_FILE_PRINT_PREVIEW)
#endif
	ToolbarItem(AP_TOOLBAR_ID_FILE_PRINT)

	Spacer()
	ToolbarItem(AP_TOOLBAR_ID_EDIT_UNDO)
	ToolbarItem(AP_TOOLBAR_ID_EDIT_REDO)

	Spacer()
	ToolbarItem(AP_TOOLBAR_ID_EDIT_CUT)
	ToolbarItem(AP_TOOLBAR_ID_EDIT_COPY)
	ToolbarItem(AP_TOOLBAR_ID_EDIT_PASTE)

	Spacer()
#ifdef ENABLE_SPELL
	ToolbarItem(AP_TOOLBAR_ID_SPELLCHECK)
#endif
	ToolbarItem(AP_TOOLBAR_ID_ZOOM)
EndLayout()
